kedro.extras.transformers.time_profiler.ProfileTimeTransformer — Kedro 0.17.6 documentation

# kedro.extras.transformers.time_profiler.ProfileTimeTransformer

class `kedro.extras.transformers.time_profiler.` `ProfileTimeTransformer`

  A transformer that logs the runtime of data set load and save calls.

  Methods

  `load`(data_set_name, load) | This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks before_dataset_loaded and after_dataset_loaded.
  `save`(data_set_name, save, data) | This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks before_dataset_saved and after_dataset_saved.

  `load`(data_set_name, load)

    This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks before_dataset_loaded and after_dataset_loaded.

    Wrap the loading of a dataset. Call `load` to get the data from the data set / next transformer.

    Parameters

      - data_set_name (`str`) – The name of the data set being loaded.

      - load (`Callable`[[], `Any`]) – A callback to retrieve the data being loaded from the data set / next transformer.

    Return type

      `Any`

    Returns

      The loaded data.

  `save`(data_set_name, save, data)

    This method will be deprecated in Kedro 0.18.0 in favour of the Dataset Hooks before_dataset_saved and after_dataset_saved.

    Wrap the saving of a dataset. Call `save` to pass the data to the data set / next transformer.

    Parameters

      - data_set_name (`str`) – The name of the data set being saved.

      - save (`Callable`[[`Any`], `None`]) – A callback to pass the data being saved on to the data set / next transformer.

      - data (`Any`) – The data being saved

    Return type

      `None`